@@ -57,7 +57,14 @@
 
 #ifdef USE_GMP
 
+// GMP must be included outside of 'extern C'
+#ifdef libGAP_GAP_IN_EXTERN_C
+}
+#endif
 #include <gmp.h>
+#ifdef libGAP_GAP_IN_EXTERN_C
+extern "C" {
+#endif
 
 #include        "gmpints.h"             /* GMP integers                    */
 
@@ -521,7 +528,7 @@ libGAP_Obj libGAP_FuncIntHexString( libGAP_Obj self,  libGAP_Obj str )
 
   len = libGAP_GET_LEN_STRING(str);
   if (len == 0) {
-    res = libGAP_INT_INTOBJ(0);
+    res = libGAP_INTOBJ_INT(0);
     return res;
   }
   if (*(libGAP_CHARS_STRING(str)) == '-') {
@@ -2037,8 +2044,8 @@ libGAP_Obj libGAP_RemInt ( libGAP_Obj opL, libGAP_Obj opR )
     }
     
     /* maybe it's trivial                                                   */
-    if ( libGAP_INTBASE % abs(libGAP_INT_INTOBJ(opR)) == 0 ) {
-      c = libGAP_ADDR_INT(opL)[0] % abs(libGAP_INT_INTOBJ(opR));
+    if ( libGAP_INTBASE % libGAP_INT_INTOBJ(libGAP_AbsInt(opR)) == 0 ) {
+      c = libGAP_ADDR_INT(opL)[0] % libGAP_INT_INTOBJ(libGAP_AbsInt(opR));
     }
     
     /* otherwise run through the left operand and divide digitwise         */
